==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/GroupIcons/Ec2InstanceContainer.md <==
# Ec2InstanceContainer


```text
aws-20210730/Resource/GroupIcons/Ec2InstanceContainer
```

```text
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')
```



| Illustration | Ec2InstanceContainer | Ec2InstanceContainerCard | Ec2InstanceContainerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainer.png) | ![illustration for Ec2InstanceContainer](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainer.Local.png) | ![illustration for Ec2InstanceContainerCard](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainerCard.Local.png) | ![illustration for Ec2InstanceContainerGroup](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainerGroup.Local.png) |




## Ec2InstanceContainer

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainer
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainer('Ec2InstanceContainer', 'Ec2 Instance Container', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainer
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainer('Ec2InstanceContainer', 'Ec2 Instance Container', 'an optional tech label')
@enduml
```

## Ec2InstanceContainerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerCard
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerCard('Ec2InstanceContainerCard', 'Ec2 Instance Container Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerCard
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerCard('Ec2InstanceContainerCard', 'Ec2 Instance Container Card', 'an optional description')
@enduml
```

## Ec2InstanceContainerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerGroup
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerGroup('Ec2InstanceContainerGroup', 'Ec2 Instance Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerGroup
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerGroup('Ec2InstanceContainerGroup', 'Ec2 Instance Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/GroupIcons/Ec2InstanceContainer.md <==
# Ec2InstanceContainer


```text
aws-20210730/Resource/GroupIcons/Ec2InstanceContainer
```

```text
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')
```



| Illustration | Ec2InstanceContainer | Ec2InstanceContainerCard | Ec2InstanceContainerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainer.png) | ![illustration for Ec2InstanceContainer](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainer.Local.png) | ![illustration for Ec2InstanceContainerCard](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainerCard.Local.png) | ![illustration for Ec2InstanceContainerGroup](../../../aws-20210730/Resource/GroupIcons/Ec2InstanceContainerGroup.Local.png) |




## Ec2InstanceContainer

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainer
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainer('Ec2InstanceContainer', 'Ec2 Instance Container', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainer
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainer('Ec2InstanceContainer', 'Ec2 Instance Container', 'an optional tech label')
@enduml
```

## Ec2InstanceContainerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerCard
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerCard('Ec2InstanceContainerCard', 'Ec2 Instance Container Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerCard
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerCard('Ec2InstanceContainerCard', 'Ec2 Instance Container Card', 'an optional description')
@enduml
```

## Ec2InstanceContainerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerGroup
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerGroup('Ec2InstanceContainerGroup', 'Ec2 Instance Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element Ec2InstanceContainerGroup
include('aws-20210730/Resource/GroupIcons/Ec2InstanceContainer')

' renders the element
Ec2InstanceContainerGroup('Ec2InstanceContainerGroup', 'Ec2 Instance Container Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
